use clap::Parser;
use std::path::PathBuf;

mod directory_processor;
mod tools;

use directory_processor::DirectoryProcessor;

pub const FILES_TO_COPY: [&str; 10] = [
    "jpg", "jpeg", "png", "gif", "bmp", "tiff", "webp", "avif", "txt", "md",
];
pub const FILES_TO_CONVERT: [&str; 3] = ["odt", "doc", "docx"];
pub const PATHS_TO_IGNORE: [&str; 5] = [".DS_Store", ".syncthing", ".sync-conflict-", ".stfolder", ".stversions"];

#[derive(Parser, Debug)]
#[command(
    author,
    version,
    about = "Convert source directory with document files (odt/doc/docx) to target path with pdf files with changes verification"
)]
struct Args {
    #[arg(help = "Source directory with .odt, .doc, or .docx files")]
    source: PathBuf,

    #[arg(help = "Target directory for PDFs converted files")]
    dest: PathBuf,
}

fn main() {
    let args = Args::parse();

    let mut processor = DirectoryProcessor::new(args.source, args.dest);
    if let Err(e) = processor.process() {
        eprintln!("Error processing directory: {}", e);
    }
}
